# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/bootstrap/v1/bootstrap.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/bootstrap/v1/bootstrap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from cerbos.cloud.bundle.v1 import bundle_pb2 as cerbos_dot_cloud_dot_bundle_dot_v1_dot_bundle__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cerbos/cloud/bootstrap/v1/bootstrap.proto\x12\x19\x63\x65rbos.cloud.bootstrap.v1\x1a\x1b\x62uf/validate/validate.proto\x1a#cerbos/cloud/bundle/v1/bundle.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x02\n\tPDPConfig\x12\x45\n\x04meta\x18\x01 \x01(\x0b\x32).cerbos.cloud.bootstrap.v1.PDPConfig.MetaB\x06\xbaH\x03\xc8\x01\x01R\x04meta\x12K\n\x0b\x62undle_info\x18\x02 \x01(\x0b\x32\".cerbos.cloud.bundle.v1.BundleInfoB\x06\xbaH\x03\xc8\x01\x01R\nbundleInfo\x1as\n\x04Meta\x12\x41\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\tcreatedAt\x12(\n\x0b\x63ommit_hash\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\ncommitHashB\x8c\x01\n!dev.cerbos.api.cloud.v1.bootstrapZGgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/bootstrap/v1;bootstrapv1\xaa\x02\x1d\x43\x65rbos.Api.Cloud.V1.Bootstrapb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.bootstrap.v1.bootstrap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!dev.cerbos.api.cloud.v1.bootstrapZGgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/bootstrap/v1;bootstrapv1\252\002\035Cerbos.Api.Cloud.V1.Bootstrap'
  _globals['_PDPCONFIG_META'].fields_by_name['created_at']._loaded_options = None
  _globals['_PDPCONFIG_META'].fields_by_name['created_at']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PDPCONFIG_META'].fields_by_name['commit_hash']._loaded_options = None
  _globals['_PDPCONFIG_META'].fields_by_name['commit_hash']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_PDPCONFIG'].fields_by_name['meta']._loaded_options = None
  _globals['_PDPCONFIG'].fields_by_name['meta']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PDPCONFIG'].fields_by_name['bundle_info']._loaded_options = None
  _globals['_PDPCONFIG'].fields_by_name['bundle_info']._serialized_options = b'\272H\003\310\001\001'
  _globals['_PDPCONFIG']._serialized_start=172
  _globals['_PDPCONFIG']._serialized_end=448
  _globals['_PDPCONFIG_META']._serialized_start=333
  _globals['_PDPCONFIG_META']._serialized_end=448
# @@protoc_insertion_point(module_scope)
