# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/apikey/v1/apikey.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/apikey/v1/apikey.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cerbos/cloud/apikey/v1/apikey.proto\x12\x16\x63\x65rbos.cloud.apikey.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1egoogle/protobuf/duration.proto\"n\n\x17IssueAccessTokenRequest\x12%\n\tclient_id\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x98\x01\x0cR\x08\x63lientId\x12,\n\rclient_secret\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0c\x63lientSecret\"\x88\x01\n\x18IssueAccessTokenResponse\x12*\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x61\x63\x63\x65ssToken\x12@\n\nexpires_in\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x06\xbaH\x03\xc8\x01\x01R\texpiresIn2\x9e\x01\n\rApiKeyService\x12w\n\x10IssueAccessToken\x12/.cerbos.cloud.apikey.v1.IssueAccessTokenRequest\x1a\x30.cerbos.cloud.apikey.v1.IssueAccessTokenResponse\"\x00\x1a\x14\xfa\xd2\xe4\x93\x02\x0e\x12\x0c\x45XPERIMENTALB\x80\x01\n\x1e\x64\x65v.cerbos.api.cloud.v1.apikeyZAgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/apikey/v1;apikeyv1\xaa\x02\x1a\x43\x65rbos.Api.Cloud.V1.ApiKeyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.apikey.v1.apikey_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036dev.cerbos.api.cloud.v1.apikeyZAgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/apikey/v1;apikeyv1\252\002\032Cerbos.Api.Cloud.V1.ApiKey'
  _globals['_ISSUEACCESSTOKENREQUEST'].fields_by_name['client_id']._loaded_options = None
  _globals['_ISSUEACCESSTOKENREQUEST'].fields_by_name['client_id']._serialized_options = b'\272H\005r\003\230\001\014'
  _globals['_ISSUEACCESSTOKENREQUEST'].fields_by_name['client_secret']._loaded_options = None
  _globals['_ISSUEACCESSTOKENREQUEST'].fields_by_name['client_secret']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ISSUEACCESSTOKENRESPONSE'].fields_by_name['access_token']._loaded_options = None
  _globals['_ISSUEACCESSTOKENRESPONSE'].fields_by_name['access_token']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_ISSUEACCESSTOKENRESPONSE'].fields_by_name['expires_in']._loaded_options = None
  _globals['_ISSUEACCESSTOKENRESPONSE'].fields_by_name['expires_in']._serialized_options = b'\272H\003\310\001\001'
  _globals['_APIKEYSERVICE']._loaded_options = None
  _globals['_APIKEYSERVICE']._serialized_options = b'\372\322\344\223\002\016\022\014EXPERIMENTAL'
  _globals['_ISSUEACCESSTOKENREQUEST']._serialized_start=153
  _globals['_ISSUEACCESSTOKENREQUEST']._serialized_end=263
  _globals['_ISSUEACCESSTOKENRESPONSE']._serialized_start=266
  _globals['_ISSUEACCESSTOKENRESPONSE']._serialized_end=402
  _globals['_APIKEYSERVICE']._serialized_start=405
  _globals['_APIKEYSERVICE']._serialized_end=563
# @@protoc_insertion_point(module_scope)
