# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/pdp/v1/pdp.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/pdp/v1/pdp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63\x65rbos/cloud/pdp/v1/pdp.proto\x12\x13\x63\x65rbos.cloud.pdp.v1\x1a\x1b\x62uf/validate/validate.proto\"T\n\nIdentifier\x12#\n\x08instance\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08instance\x12!\n\x07version\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x07versionBt\n\x1b\x64\x65v.cerbos.api.cloud.v1.pdpZ;github.com/cerbos/cloud-api/genpb/cerbos/cloud/pdp/v1;pdpv1\xaa\x02\x17\x43\x65rbos.Api.Cloud.V1.Pdpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.pdp.v1.pdp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033dev.cerbos.api.cloud.v1.pdpZ;github.com/cerbos/cloud-api/genpb/cerbos/cloud/pdp/v1;pdpv1\252\002\027Cerbos.Api.Cloud.V1.Pdp'
  _globals['_IDENTIFIER'].fields_by_name['instance']._loaded_options = None
  _globals['_IDENTIFIER'].fields_by_name['instance']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_IDENTIFIER'].fields_by_name['version']._loaded_options = None
  _globals['_IDENTIFIER'].fields_by_name['version']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_IDENTIFIER']._serialized_start=83
  _globals['_IDENTIFIER']._serialized_end=167
# @@protoc_insertion_point(module_scope)
