# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cerbos.cloud.store.v1 import store_pb2 as cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2


class CerbosStoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFiles = channel.unary_unary(
                '/cerbos.cloud.store.v1.CerbosStoreService/ListFiles',
                request_serializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ListFilesRequest.SerializeToString,
                response_deserializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ListFilesResponse.FromString,
                _registered_method=True)
        self.GetFiles = channel.unary_unary(
                '/cerbos.cloud.store.v1.CerbosStoreService/GetFiles',
                request_serializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.GetFilesRequest.SerializeToString,
                response_deserializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.GetFilesResponse.FromString,
                _registered_method=True)
        self.ModifyFiles = channel.unary_unary(
                '/cerbos.cloud.store.v1.CerbosStoreService/ModifyFiles',
                request_serializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ModifyFilesRequest.SerializeToString,
                response_deserializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ModifyFilesResponse.FromString,
                _registered_method=True)
        self.ReplaceFiles = channel.unary_unary(
                '/cerbos.cloud.store.v1.CerbosStoreService/ReplaceFiles',
                request_serializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ReplaceFilesRequest.SerializeToString,
                response_deserializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ReplaceFilesResponse.FromString,
                _registered_method=True)


class CerbosStoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifyFiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReplaceFiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CerbosStoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFiles,
                    request_deserializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ListFilesRequest.FromString,
                    response_serializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ListFilesResponse.SerializeToString,
            ),
            'GetFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFiles,
                    request_deserializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.GetFilesRequest.FromString,
                    response_serializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.GetFilesResponse.SerializeToString,
            ),
            'ModifyFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ModifyFiles,
                    request_deserializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ModifyFilesRequest.FromString,
                    response_serializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ModifyFilesResponse.SerializeToString,
            ),
            'ReplaceFiles': grpc.unary_unary_rpc_method_handler(
                    servicer.ReplaceFiles,
                    request_deserializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ReplaceFilesRequest.FromString,
                    response_serializer=cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ReplaceFilesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cerbos.cloud.store.v1.CerbosStoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cerbos.cloud.store.v1.CerbosStoreService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CerbosStoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cerbos.cloud.store.v1.CerbosStoreService/ListFiles',
            cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ListFilesRequest.SerializeToString,
            cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ListFilesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cerbos.cloud.store.v1.CerbosStoreService/GetFiles',
            cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.GetFilesRequest.SerializeToString,
            cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.GetFilesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModifyFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cerbos.cloud.store.v1.CerbosStoreService/ModifyFiles',
            cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ModifyFilesRequest.SerializeToString,
            cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ModifyFilesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReplaceFiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cerbos.cloud.store.v1.CerbosStoreService/ReplaceFiles',
            cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ReplaceFilesRequest.SerializeToString,
            cerbos_dot_cloud_dot_store_dot_v1_dot_store__pb2.ReplaceFilesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
