# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/epdp/v1/epdp.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/epdp/v1/epdp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cerbos.policy.v1 import policy_pb2 as cerbos_dot_policy_dot_v1_dot_policy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63\x65rbos/cloud/epdp/v1/epdp.proto\x12\x14\x63\x65rbos.cloud.epdp.v1\x1a\x1d\x63\x65rbos/policy/v1/policy.proto\"\xda\x02\n\x08Metadata\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x1e\n\x08policies\x18\x02 \x03(\tB\x02\x18\x01R\x08policies\x12\'\n\x0f\x62uild_timestamp\x18\x03 \x01(\x03R\x0e\x62uildTimestamp\x12\x1f\n\x0b\x63ommit_hash\x18\x04 \x01(\tR\ncommitHash\x12\x61\n\x11source_attributes\x18\x05 \x03(\x0b\x32\x34.cerbos.cloud.epdp.v1.Metadata.SourceAttributesEntryR\x10sourceAttributes\x1ag\n\x15SourceAttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\".cerbos.policy.v1.SourceAttributesR\x05value:\x02\x38\x01\x42x\n\x1c\x64\x65v.cerbos.api.cloud.v1.epdpZ=github.com/cerbos/cloud-api/genpb/cerbos/cloud/epdp/v1;epdpv1\xaa\x02\x18\x43\x65rbos.Api.Cloud.V1.Epdpb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.epdp.v1.epdp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034dev.cerbos.api.cloud.v1.epdpZ=github.com/cerbos/cloud-api/genpb/cerbos/cloud/epdp/v1;epdpv1\252\002\030Cerbos.Api.Cloud.V1.Epdp'
  _globals['_METADATA_SOURCEATTRIBUTESENTRY']._loaded_options = None
  _globals['_METADATA_SOURCEATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_METADATA'].fields_by_name['policies']._loaded_options = None
  _globals['_METADATA'].fields_by_name['policies']._serialized_options = b'\030\001'
  _globals['_METADATA']._serialized_start=89
  _globals['_METADATA']._serialized_end=435
  _globals['_METADATA_SOURCEATTRIBUTESENTRY']._serialized_start=332
  _globals['_METADATA_SOURCEATTRIBUTESENTRY']._serialized_end=435
# @@protoc_insertion_point(module_scope)
