# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cerbos/cloud/bundle/v1/bundle.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cerbos/cloud/bundle/v1/bundle.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from cerbos.cloud.pdp.v1 import pdp_pb2 as cerbos_dot_cloud_dot_pdp_dot_v1_dot_pdp__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cerbos/cloud/bundle/v1/bundle.proto\x12\x16\x63\x65rbos.cloud.bundle.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1d\x63\x65rbos/cloud/pdp/v1/pdp.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb7\x02\n\nBundleInfo\x12\x1d\n\x05label\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x05label\x12(\n\x0b\x62undle_hash\x18\x02 \x01(\x0c\x42\x07\xbaH\x04z\x02h R\nbundleHash\x12P\n\x08segments\x18\x03 \x03(\x0b\x32*.cerbos.cloud.bundle.v1.BundleInfo.SegmentB\x08\xbaH\x05\x92\x01\x02\x08\x01R\x08segments\x1a\x8d\x01\n\x07Segment\x12&\n\nsegment_id\x18\x01 \x01(\rB\x07\xbaH\x04*\x02 \x00R\tsegmentId\x12#\n\x08\x63hecksum\x18\x02 \x01(\x0c\x42\x07\xbaH\x04z\x02h R\x08\x63hecksum\x12\x35\n\rdownload_urls\x18\x03 \x03(\tB\x10\xbaH\r\x92\x01\n\x08\x01\x18\x01\"\x04r\x02\x10\x01R\x0c\x64ownloadUrls\">\n\x04Meta\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x16\n\x06source\x18\x02 \x01(\tR\x06source\"\x8d\x02\n\x08Manifest\x12\x1f\n\x0b\x61pi_version\x18\x01 \x01(\tR\napiVersion\x12T\n\x0cpolicy_index\x18\x02 \x03(\x0b\x32\x31.cerbos.cloud.bundle.v1.Manifest.PolicyIndexEntryR\x0bpolicyIndex\x12\x18\n\x07schemas\x18\x03 \x03(\tR\x07schemas\x12\x30\n\x04meta\x18\x04 \x01(\x0b\x32\x1c.cerbos.cloud.bundle.v1.MetaR\x04meta\x1a>\n\x10PolicyIndexEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"~\n\x10GetBundleRequest\x12>\n\x06pdp_id\x18\x01 \x01(\x0b\x32\x1f.cerbos.cloud.pdp.v1.IdentifierB\x06\xbaH\x03\xc8\x01\x01R\x05pdpId\x12*\n\x0c\x62undle_label\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x62undleLabel\"`\n\x11GetBundleResponse\x12K\n\x0b\x62undle_info\x18\x01 \x01(\x0b\x32\".cerbos.cloud.bundle.v1.BundleInfoB\x06\xbaH\x03\xc8\x01\x01R\nbundleInfo\"\xcf\x03\n\x12WatchBundleRequest\x12>\n\x06pdp_id\x18\x01 \x01(\x0b\x32\x1f.cerbos.cloud.pdp.v1.IdentifierB\x06\xbaH\x03\xc8\x01\x01R\x05pdpId\x12X\n\x0bwatch_label\x18\x02 \x01(\x0b\x32\x35.cerbos.cloud.bundle.v1.WatchBundleRequest.WatchLabelH\x00R\nwatchLabel\x12T\n\theartbeat\x18\x03 \x01(\x0b\x32\x34.cerbos.cloud.bundle.v1.WatchBundleRequest.HeartbeatH\x00R\theartbeat\x1a\x38\n\nWatchLabel\x12*\n\x0c\x62undle_label\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0b\x62undleLabel\x1a\x87\x01\n\tHeartbeat\x12G\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xbaH\n\xb2\x01\x04J\x02\x08<\xc8\x01\x01R\ttimestamp\x12\x31\n\x10\x61\x63tive_bundle_id\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x0e\x61\x63tiveBundleIdB\x05\n\x03msg\"\x94\x03\n\x13WatchBundleResponse\x12I\n\rbundle_update\x18\x01 \x01(\x0b\x32\".cerbos.cloud.bundle.v1.BundleInfoH\x00R\x0c\x62undleUpdate\x12U\n\treconnect\x18\x02 \x01(\x0b\x32\x35.cerbos.cloud.bundle.v1.WatchBundleResponse.ReconnectH\x00R\treconnect\x12\x62\n\x0e\x62undle_removed\x18\x03 \x01(\x0b\x32\x39.cerbos.cloud.bundle.v1.WatchBundleResponse.BundleRemovedH\x00R\rbundleRemoved\x1aX\n\tReconnect\x12\x33\n\x07\x62\x61\x63koff\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07\x62\x61\x63koff\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\x1a\x0f\n\rBundleRemovedB\x0c\n\x03msg\x12\x05\xbaH\x02\x08\x01\x32\xfd\x01\n\x13\x43\x65rbosBundleService\x12\x62\n\tGetBundle\x12(.cerbos.cloud.bundle.v1.GetBundleRequest\x1a).cerbos.cloud.bundle.v1.GetBundleResponse\"\x00\x12l\n\x0bWatchBundle\x12*.cerbos.cloud.bundle.v1.WatchBundleRequest\x1a+.cerbos.cloud.bundle.v1.WatchBundleResponse\"\x00(\x01\x30\x01\x1a\x14\xfa\xd2\xe4\x93\x02\x0e\x12\x0c\x45XPERIMENTALB\x80\x01\n\x1e\x64\x65v.cerbos.api.cloud.v1.bundleZAgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/bundle/v1;bundlev1\xaa\x02\x1a\x43\x65rbos.Api.Cloud.V1.Bundleb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cerbos.cloud.bundle.v1.bundle_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036dev.cerbos.api.cloud.v1.bundleZAgithub.com/cerbos/cloud-api/genpb/cerbos/cloud/bundle/v1;bundlev1\252\002\032Cerbos.Api.Cloud.V1.Bundle'
  _globals['_BUNDLEINFO_SEGMENT'].fields_by_name['segment_id']._loaded_options = None
  _globals['_BUNDLEINFO_SEGMENT'].fields_by_name['segment_id']._serialized_options = b'\272H\004*\002 \000'
  _globals['_BUNDLEINFO_SEGMENT'].fields_by_name['checksum']._loaded_options = None
  _globals['_BUNDLEINFO_SEGMENT'].fields_by_name['checksum']._serialized_options = b'\272H\004z\002h '
  _globals['_BUNDLEINFO_SEGMENT'].fields_by_name['download_urls']._loaded_options = None
  _globals['_BUNDLEINFO_SEGMENT'].fields_by_name['download_urls']._serialized_options = b'\272H\r\222\001\n\010\001\030\001\"\004r\002\020\001'
  _globals['_BUNDLEINFO'].fields_by_name['label']._loaded_options = None
  _globals['_BUNDLEINFO'].fields_by_name['label']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_BUNDLEINFO'].fields_by_name['bundle_hash']._loaded_options = None
  _globals['_BUNDLEINFO'].fields_by_name['bundle_hash']._serialized_options = b'\272H\004z\002h '
  _globals['_BUNDLEINFO'].fields_by_name['segments']._loaded_options = None
  _globals['_BUNDLEINFO'].fields_by_name['segments']._serialized_options = b'\272H\005\222\001\002\010\001'
  _globals['_MANIFEST_POLICYINDEXENTRY']._loaded_options = None
  _globals['_MANIFEST_POLICYINDEXENTRY']._serialized_options = b'8\001'
  _globals['_GETBUNDLEREQUEST'].fields_by_name['pdp_id']._loaded_options = None
  _globals['_GETBUNDLEREQUEST'].fields_by_name['pdp_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETBUNDLEREQUEST'].fields_by_name['bundle_label']._loaded_options = None
  _globals['_GETBUNDLEREQUEST'].fields_by_name['bundle_label']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_GETBUNDLERESPONSE'].fields_by_name['bundle_info']._loaded_options = None
  _globals['_GETBUNDLERESPONSE'].fields_by_name['bundle_info']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WATCHBUNDLEREQUEST_WATCHLABEL'].fields_by_name['bundle_label']._loaded_options = None
  _globals['_WATCHBUNDLEREQUEST_WATCHLABEL'].fields_by_name['bundle_label']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WATCHBUNDLEREQUEST_HEARTBEAT'].fields_by_name['timestamp']._loaded_options = None
  _globals['_WATCHBUNDLEREQUEST_HEARTBEAT'].fields_by_name['timestamp']._serialized_options = b'\272H\n\262\001\004J\002\010<\310\001\001'
  _globals['_WATCHBUNDLEREQUEST_HEARTBEAT'].fields_by_name['active_bundle_id']._loaded_options = None
  _globals['_WATCHBUNDLEREQUEST_HEARTBEAT'].fields_by_name['active_bundle_id']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_WATCHBUNDLEREQUEST'].fields_by_name['pdp_id']._loaded_options = None
  _globals['_WATCHBUNDLEREQUEST'].fields_by_name['pdp_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_WATCHBUNDLERESPONSE'].oneofs_by_name['msg']._loaded_options = None
  _globals['_WATCHBUNDLERESPONSE'].oneofs_by_name['msg']._serialized_options = b'\272H\002\010\001'
  _globals['_CERBOSBUNDLESERVICE']._loaded_options = None
  _globals['_CERBOSBUNDLESERVICE']._serialized_options = b'\372\322\344\223\002\016\022\014EXPERIMENTAL'
  _globals['_BUNDLEINFO']._serialized_start=218
  _globals['_BUNDLEINFO']._serialized_end=529
  _globals['_BUNDLEINFO_SEGMENT']._serialized_start=388
  _globals['_BUNDLEINFO_SEGMENT']._serialized_end=529
  _globals['_META']._serialized_start=531
  _globals['_META']._serialized_end=593
  _globals['_MANIFEST']._serialized_start=596
  _globals['_MANIFEST']._serialized_end=865
  _globals['_MANIFEST_POLICYINDEXENTRY']._serialized_start=803
  _globals['_MANIFEST_POLICYINDEXENTRY']._serialized_end=865
  _globals['_GETBUNDLEREQUEST']._serialized_start=867
  _globals['_GETBUNDLEREQUEST']._serialized_end=993
  _globals['_GETBUNDLERESPONSE']._serialized_start=995
  _globals['_GETBUNDLERESPONSE']._serialized_end=1091
  _globals['_WATCHBUNDLEREQUEST']._serialized_start=1094
  _globals['_WATCHBUNDLEREQUEST']._serialized_end=1557
  _globals['_WATCHBUNDLEREQUEST_WATCHLABEL']._serialized_start=1356
  _globals['_WATCHBUNDLEREQUEST_WATCHLABEL']._serialized_end=1412
  _globals['_WATCHBUNDLEREQUEST_HEARTBEAT']._serialized_start=1415
  _globals['_WATCHBUNDLEREQUEST_HEARTBEAT']._serialized_end=1550
  _globals['_WATCHBUNDLERESPONSE']._serialized_start=1560
  _globals['_WATCHBUNDLERESPONSE']._serialized_end=1964
  _globals['_WATCHBUNDLERESPONSE_RECONNECT']._serialized_start=1845
  _globals['_WATCHBUNDLERESPONSE_RECONNECT']._serialized_end=1933
  _globals['_WATCHBUNDLERESPONSE_BUNDLEREMOVED']._serialized_start=1935
  _globals['_WATCHBUNDLERESPONSE_BUNDLEREMOVED']._serialized_end=1950
  _globals['_CERBOSBUNDLESERVICE']._serialized_start=1967
  _globals['_CERBOSBUNDLESERVICE']._serialized_end=2220
# @@protoc_insertion_point(module_scope)
